@@ -4,6 +4,7 @@ use Mojolicious::Plugin::AssetPack::Util qw(checksum diag DEBUG);
 use IO::Compress::Gzip 'gzip';
  
 has enabled => sub { shift->assetpack->minify };
+has app => sub { shift->assetpack->app };
 has config => sub { my $self = shift; my $config = $self->assetpack->config || $self->assetpack->config({}); $config->{CombineFile} ||= {}; };
 has serve => sub { shift->assetpack->serve_cb };
 
@@ -39,7 +40,7 @@ sub process {
   if (@$combine) {
     my $format = $combine->[0]->format;
     #~ my $checksum = checksum $topic;
-    my $checksum = checksum $topic.($self->config->{version} || '');#$combine->map('url')->join(':');
+    my $checksum = checksum $topic.($self->app->config('version') // $self->app->config('версия') // '');#$combine->map('url')->join(':');
     
     #~ warn "Process CombineFile: ", $self->assetpack->app->dumper($combine), $checksum;
     
@@ -76,7 +77,7 @@ sub process {
     
     if ($self->config->{gzip} && ($self->config->{gzip}{min_size} || 1000) < $content->size) {
       gzip \($content->to_string) => \(my $gzip), {-Level => 9};
-      my $checksum_gzip = checksum($topic.($self->config->{version} || '').'.gzip');
+      my $checksum_gzip = checksum($topic.($self->app->config('version') // $self->app->config('версия') // '').'.gzip');
       DEBUG && diag 'GZIP asset topic=[%s] with checksum=[%s] and format=[%s] and rate=[%s/%s].', $topic, $checksum, $format, $content->size, length($gzip);
       $self->assetpack->{by_checksum}{$checksum_gzip} = $self->assetpack->store->save(\$gzip, {key => "combine-file-gzip", url=>$topic.'.gzip', name=>$topic.'.gzip', checksum=>$checksum_gzip, minified=>1, format=>$format,});
       
@@ -93,8 +94,8 @@ sub _cb_route_by_topic {
 return sub {
   my $c  = shift;
   my $topic = $c->stash('topic');
-  $c->stash('name'=>checksum $topic.($self->config->{version} || ''));
-  $c->stash('checksum'=>checksum $topic.($self->config->{version} || ''));
+  $c->stash('name'=>checksum $topic.($self->app->config('version') // $self->app->config('версия') // ''));
+  $c->stash('checksum'=>checksum $topic.($self->app->config('version') // $self->app->config('версия') // ''));
   return $self->serve->($c);
   
    #~ my $assets = $assetpack->processed($topic)
